diff libmpcodecs/vf_scale.c @ 9071:25baacd1c650

UYVY input
author michael
date Thu, 23 Jan 2003 09:35:22 +0000
parents 29c059774519
children 898e5270a46e
line wrap: on
line diff
--- a/libmpcodecs/vf_scale.c	Thu Jan 23 04:19:24 2003 +0000
+++ b/libmpcodecs/vf_scale.c	Thu Jan 23 09:35:22 2003 +0000
@@ -219,13 +219,14 @@
 
 //===========================================================================//
 
 //  supported Input formats: YV12, I420, IYUV, YUY2, BGR32, BGR24, BGR16, BGR15, RGB32, RGB24, Y8, Y800
 
 static int query_format(struct vf_instance_s* vf, unsigned int fmt){
     switch(fmt){
     case IMGFMT_YV12:
     case IMGFMT_I420:
     case IMGFMT_IYUV:
+    case IMGFMT_UYVY:
     case IMGFMT_YUY2:
     case IMGFMT_BGR32:
     case IMGFMT_BGR24:
@@ -219,13 +219,14 @@
 //===========================================================================//
 
-//  supported Input formats: YV12, I420, IYUV, YUY2, BGR32, BGR24, BGR16, BGR15, RGB32, RGB24, Y8, Y800
+//  supported Input formats: YV12, I420, IYUV, YUY2, UYVY, BGR32, BGR24, BGR16, BGR15, RGB32, RGB24, Y8, Y800
 
 static int query_format(struct vf_instance_s* vf, unsigned int fmt){